==> qiho-center-api-1.0.3-sources.jar: com/qiho/center/api/dto/logistics/QueryTYOLogisticsMsgDto.java <==
package com.qiho.center.api.dto.logistics;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.qiho.center.api.dto.BaseDto;

/**
 * ClassName: QueryLogisticsOrderDto <br/>
 * Function: 圆通订单物流信息推送DTO. <br/>
 * date: 2017年6月3日 下午2:55:11 <br/>
 *
 * @author chencheng
 * @version
 */
@XmlRootElement(name = "UpdateInfo")
// 控制JAXB 绑定类中属性和字段的排序
@XmlType(propOrder = { "txLogisticID", "mailNo", "infoContent", "remark" })
public class QueryTYOLogisticsMsgDto extends BaseDto {

    private static final long serialVersionUID = 5323935025690538152L;

    /** 物流号 */
    private String            txLogisticID;

    /** 物流运单号 */
    private String            mailNo;

    /** 操作，对应于YTOLogisticsStatusEnum.java */
    private String            infoContent;

    /** 备注或失败原因（值为中文原因或备注） */
    private String            remark;

    /**
     * mailNo.
     *
     * @return the mailNo
     */
    public String getMailNo() {
        return mailNo;
    }

    /**
     * mailNo.
     *
     * @param mailNo the mailNo to set
     */
    public void setMailNo(String mailNo) {
        this.mailNo = mailNo;
    }

    /**
     * txLogisticID.
     *
     * @return the txLogisticID
     */
    public String getTxLogisticID() {
        return txLogisticID;
    }

    /**
     * txLogisticID.
     *
     * @param txLogisticID the txLogisticID to set
     */
    public void setTxLogisticID(String txLogisticID) {
        this.txLogisticID = txLogisticID;
    }

    /**
     * infoContent.
     *
     * @return the infoContent
     */
    public String getInfoContent() {
        return infoContent;
    }

    /**
     * infoContent.
     *
     * @param infoContent the infoContent to set
     */
    public void setInfoContent(String infoContent) {
        this.infoContent = infoContent;
    }

    /**
     * remark.
     *
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * remark.
     *
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

}

==> qiho-center-api-2.9.6-20210525.064243-1-sources.jar: com/qiho/center/api/dto/logistics/QueryTYOLogisticsMsgDto.java <==
package com.qiho.center.api.dto.logistics;

import com.qiho.center.api.dto.BaseDto;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * ClassName: QueryLogisticsOrderDto <br/>
 * Function: 圆通订单物流信息推送DTO. <br/>
 * date: 2017年6月3日 下午2:55:11 <br/>
 *
 * @author chencheng
 * @version
 */
@XmlRootElement(name = "UpdateInfo")
//控制JAXB 绑定类中属性和字段的排序
@XmlType(propOrder = { "txLogisticID", "infoContent","mailNo","deliveryName","contactInfo","remark"})
public class QueryTYOLogisticsMsgDto extends BaseDto {

    private static final long serialVersionUID = 5323935025690538152L;

    /** 物流号 */
    private String            txLogisticID;

    /** 操作，对应于YTOLogisticsStatusEnum.java */
    private String            infoContent;

    /** 物流运单号 */
    private String            mailNo;

    /** 操作人员姓名，签收、派送、揽件 */
    private String            deliveryName;

    /** 操作人员联系方式 */
    private String            contactInfo;

    /** 备注或失败原因（值为中文原因或备注） */
    private String            remark;

    /**
     * mailNo.
     *
     * @return the mailNo
     */
    public String getMailNo() {
        return mailNo;
    }

    /**
     * mailNo.
     *
     * @param mailNo the mailNo to set
     */
    public void setMailNo(String mailNo) {
        this.mailNo = mailNo;
    }

    /**
     * txLogisticID.
     *
     * @return the txLogisticID
     */
    public String getTxLogisticID() {
        return txLogisticID;
    }

    /**
     * txLogisticID.
     *
     * @param txLogisticID the txLogisticID to set
     */
    public void setTxLogisticID(String txLogisticID) {
        this.txLogisticID = txLogisticID;
    }

    /**
     * infoContent.
     *
     * @return the infoContent
     */
    public String getInfoContent() {
        return infoContent;
    }

    /**
     * infoContent.
     *
     * @param infoContent the infoContent to set
     */
    public void setInfoContent(String infoContent) {
        this.infoContent = infoContent;
    }

    /**
     * remark.
     *
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * remark.
     *
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getDeliveryName() {
        return deliveryName;
    }

    public void setDeliveryName(String deliveryName) {
        this.deliveryName = deliveryName;
    }

    public String getContactInfo() {
        return contactInfo;
    }

    public void setContactInfo(String contactInfo) {
        this.contactInfo = contactInfo;
    }
}
